@@ -136,6 +136,8 @@ def blync_callback(
 ):
     """Control your Embrava BlyncLight from the command-line!
 
+    ## Usage
+
     Use the `blync` utility to directly control your Embrava BlyncLight:
 
     \b
@@ -170,8 +172,7 @@ def blync_callback(
     $ blync rainbow
     ```
 
-
-    Installation
+    ## Installation
 
     \b
     ```console
@@ -186,9 +187,9 @@ def blync_callback(
 
     try:
         light = BlyncLight.get_light(light_id, immediate=False)
-    except Exception as error:
+    except BlyncLightNotFound as error:
         typer.secho(str(error), fg="red")
-        raise typer.Exit(-1)
+        raise typer.Exit(-1) from None
 
     assert light.immediate == 0
 
@@ -208,10 +209,14 @@ def blync_callback(
     if not ctx.invoked_subcommand:
         if light.on and light.color == (0, 0, 0):
             light.color = DEFAULT_COLOR
-        light.immediate = 1
-        if verbose:
-            print(light)
-        typer.Exit()
+        try:
+            light.immediate = 1
+            if verbose:
+                print(light)
+            typer.Exit()
+        except Exception as error:
+            typer.secho(str(error), fg="red")
+            raise typer.Exit(-1) from None
 
     # Disable flashing for subcommands.
     light.flash = 0
@@ -236,6 +241,8 @@ def fli_subcommand(
     user can specify the interval between color changes and the intesity
     of the colors. Color values specified on the command-line are ignored.
 
+    ## Examples
+
     \b
     ```console
     $ blync fli -n 1      # one second between color changes
@@ -276,6 +283,8 @@ def throbber_subcommand(
     intensity up and down and repeating. The user can increase the rate
     of ramp by adding more -f options to the command line:
 
+    ## Examples
+
     \b
     ```console
     $ blync throbber -f   # a little faster
@@ -326,6 +335,8 @@ def rainbow_subcommand(
     The user can slow the speed of the color cycling by adding more
     --slow options to the command line:
 
+    ## Examples
+
     \b
     ```console
     $ blync rainbow -s   # slow cycling by 0.1 seconds
